@@ -86,9 +86,9 @@ $('div.important > p.admonition-title').prepend('<div class="fa fa-fw fa-check-c
 $('div.note > p.admonition-title').prepend('<div class="fa fa-fw fa-check-circle">&nbsp;</div>');
 $('div.seealso > p.admonition-title').prepend('<div class="fa fa-fw fa-info-circle">&nbsp;</div>');
 $('div.warning > p.admonition-title').prepend('<div class="fa fa-fw fa-exclamation-triangle">&nbsp;</div>');
-$('div.versionadded > p').first().prepend('<div class="fa fa-fw fa-plus-circle">&nbsp;</div>');
-$('div.versionchanged > p').first().prepend('<div class="fa fa-fw fa-info-circle">&nbsp;</div>');
-$('div.deprecated > p').first().prepend('<div class="fa fa-fw fa-minus-circle">&nbsp;</div>');
+$('div.versionadded > p').prepend('<div class="fa fa-fw fa-plus-circle">&nbsp;</div>');
+$('div.versionchanged > p').prepend('<div class="fa fa-fw fa-info-circle">&nbsp;</div>');
+$('div.deprecated > p').prepend('<div class="fa fa-fw fa-minus-circle">&nbsp;</div>');
 
 /* BB 150310
    We also insert a space between the icon and the admonition title
@@ -129,10 +129,10 @@ function logABug(bugTitle, bugProject, fieldComment, fieldTags) {
         bugLink = urlBase + bugProject;
     } else {
         bugLink = urlBase  + encodeURIComponent(bugTitle) +
+        "&field.tags=" + fieldTags +
         "&field.comment=" + lineFeed + lineFeed +  lineFeed +
         bugChecklist + lineFeed + "-----------------------------------" + lineFeed + fieldComment +
-        lineFeed + currentURL +
-        "&field.tags=" + fieldTags;
+        lineFeed + currentURL;
     }
     document.getElementById("logABugLink1").href=bugLink;
     document.getElementById("logABugLink2").href=bugLink;
